Software Summary and Comparisons
=================================

.. note:: This page is actively updated, since many open-source software are missed here.

`pygmo <https://esa.github.io/pygmo2/>`_ is *a scientific Python library for massively parallel optimization*.
  * https://esa.github.io/pygmo2/algorithms.html#pygmo.de
  * https://esa.github.io/pygmo2/algorithms.html#pygmo.sade
  * https://esa.github.io/pygmo2/algorithms.html#pygmo.de1220
  * https://esa.github.io/pygmo2/algorithms.html#pygmo.pso
  * https://esa.github.io/pygmo2/algorithms.html#pygmo.pso_gen
  * https://esa.github.io/pygmo2/algorithms.html#pygmo.sea
  * https://esa.github.io/pygmo2/algorithms.html#pygmo.sga
  * https://esa.github.io/pygmo2/algorithms.html#pygmo.simulated_annealing
  * https://esa.github.io/pygmo2/algorithms.html#pygmo.cmaes
  * https://esa.github.io/pygmo2/algorithms.html#pygmo.xnes

`IOHanalyzer <https://github.com/IOHprofiler/IOHanalyzer>`_ is *a performance analyzer for Iterative Optimization Heuristics (IOHs)*.

https://nlopt.readthedocs.io/en/latest/

https://coin-or.github.io/Ipopt/

https://scipy.org/

R for Statistical Computing
------

https://cran.r-project.org/web/views/Optimization.html

* https://cran.r-project.org/web/packages/cmaes/index.html

* https://cran.r-project.org/web/packages/CEoptim/index.html

* https://cran.r-project.org/web/packages/DEoptimR/index.html

  Currently, it only provides an implementation of the `jDE` algorithm by Brest et al. (2006).

CMA-ES
------

* https://github.com/CMA-ES
